<?php

namespace Drupal\zeptomail\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\JsonResponse;
use Drupal\zeptomail\Helper\ZeptoMailApi;
use Drupal\Core\Access\CsrfTokenGenerator;

class ZeptoMailController extends ControllerBase {

  /**
   * Render the admin page with a Twig template and custom JavaScript.
   */
  public function adminPage() {
    // Data to pass to the Twig template.
    $config = \Drupal::config('zeptomail.settings');
    $csrf_service = \Drupal::service('csrf_token');
    $csrf_token = $csrf_service->get('zeptomail_config_form');

    // Get specific configuration values.
    $is_enabled = $config->get('is_enabled');
    if(!empty($is_enabled)  && $is_enabled ){
      $domain = $config->get('domain');
      $mailtoken = base64_decode($config->get('mailtoken'));
      $from_address = $config->get('from_address');
      $from_name = $config->get('from_name');
    } 
    else {
      $domain = '';
      $mailtoken = '';
      $from_address = '';
      $from_name = '';
    }
    $data = [
      'domain' => $domain,
      'mailtoken' => $mailtoken,
      'from_address' => $from_address,
      'from_name' => $from_name,
      'csrf_token' => $csrf_token
    ];

    return [
      '#theme' => 'zeptomail_admin_page_js',
      '#data' => $data,
      '#csrftoken' => $csrf_token,
      '#attached' => [
        'library' => [
          'zeptomail/admin_page_js',
        ],
      ],
    ];
  }
  
  public function testZeptoMailConfig() {
    
    $config = \Drupal::config('zeptomail.settings');
    $domain = $config->get('domain');
    $mailtoken = base64_decode($config->get('mailtoken'));
    $from_address = $config->get('from_address');
    $from_name = $config->get('from_name');
    $respObj = json_decode("{}",true);
    $request = \Drupal::request()->request;
    $csrf_service = \Drupal::service('csrf_token');
    $zepto_csrftoken = $request->get('zepto_csrftoken');
    
    if (!$csrf_service->validate($zepto_csrftoken, 'zeptomail_config_form')) {
      $respObj["result"] = "failure";
      $respObj['error_message'] = "Invalid request";
    }

    $zeptoAPI = new ZeptoMailApi($domain,$mailtoken);
    $mailRes = $this->sendTestMail($from_address,$zeptoAPI);
    
    if($mailRes->result !== "success") {
      $errorCode = $mailRes->details->code;
      $respObj["result"] = "failure";
      if($errorCode === 'SERR_157'){
        $respObj['error_message'] = "Enter valid send mail token to complete configuration";
      } else{
        $respObj['error_message'] = $mailRes->details->message;
      }
    } 
    else {
      $respObj["result"] = "success";
    }
  
      return new JsonResponse($respObj);
  }
  public function configureZeptoMail() {
    $request = \Drupal::request()->request;
    $domain = $request->get('domain');
    $mailtoken = $request->get('mailtoken');
    $from_address = $request->get('from_address');
    $from_name = $request->get('from_name');
    $csrf_service = \Drupal::service('csrf_token');
    $zepto_csrftoken = $request->get('zepto_csrftoken');
    $respObj = json_decode("{}",true);
    $request = \Drupal::request()->request;
    if (!$csrf_service->validate($zepto_csrftoken, 'zeptomail_config_form')) {
      $respObj["result"] = "failure";
      $respObj['error_message'] = "Invalid request";
      return $this->writeJSONResponse($respObj);
    }

    $zeptoAPI = new ZeptoMailApi($domain,$mailtoken);
    $mailRes = $this->sendTestMail($from_address,$zeptoAPI);
    
    if($mailRes->result !== "success") {
      $errorCode = $mailRes->details->code;
      $respObj["result"] = "failure";
      if($errorCode === 'SERR_157'){
        $respObj['error_message'] = "Enter valid send mail token to complete configuration";
      } else{
        $respObj['error_message'] = $mailRes->details->message;
      }
    } 
    else {
      $config = \Drupal::configFactory()->getEditable('zeptomail.settings');
      $config->set('domain', $domain)
            ->set('mailtoken', base64_encode($mailtoken))
            ->set('from_address', $from_address)
            ->set('from_name', $from_name)
            ->set('is_enabled', true)
            ->save();
      $respObj["result"] = "success";
    }
  
      return $this->writeJSONResponse($respObj);
  }
  private function sendTestMail($fromAddress,$zeptoMailApi)
    {
		$mail_data = array();
		$from = json_decode('{}');
		$from->address = $fromAddress;
		$emailDetail = array();
		$toArray = array();
		
		$mail_data['from'] = ['address' => $fromAddress];
		
		$emailDetail["email_address"] = ['address' => $fromAddress];
		array_push($toArray,$emailDetail);
		
		$mail_data['to'] = $toArray;
		$mail_data['subject'] = "this is test mail ";
		$mail_data['htmlbody'] = "This is test mail, zeptomail configured successfully ";
		
		return $zeptoMailApi->sendZeptoMail($mail_data);
        
    }
    private function writeJSONResponse($jsonMessage) {
      return new JsonResponse($jsonMessage);
    }
}
